@@ -21,7 +21,6 @@ from csle_rest_api.pages.training.routes import get_training_page_bp
 from csle_rest_api.pages.sdn_controllers.routes import get_sdn_controllers_page_bp
 from csle_rest_api.pages.control_plane.routes import get_control_plane_page_bp
 from csle_rest_api.pages.user_admin.routes import get_user_admin_page_bp
-from csle_rest_api.pages.host_terminal.routes import get_host_terminal_page_bp
 from csle_rest_api.pages.container_terminal.routes import get_container_terminal_page_bp
 from csle_rest_api.pages.system_admin.routes import get_system_admin_page_bp
 from csle_rest_api.pages.logs_admin.routes import get_logs_admin_page_bp
@@ -31,6 +30,11 @@ from csle_rest_api.resources.prometheus.routes import prometheus_bp
 from csle_rest_api.resources.cadvisor.routes import cadvisor_bp
 from csle_rest_api.resources.pgadmin.routes import pgadmin_bp
 from csle_rest_api.resources.grafana.routes import grafana_bp
+from csle_rest_api.resources.cluster_status.routes import cluster_status_bp
+from csle_rest_api.resources.nginx.routes import nginx_bp
+from csle_rest_api.resources.postgresql.routes import postgresql_bp
+from csle_rest_api.resources.flask.routes import flask_bp
+from csle_rest_api.resources.docker.routes import docker_bp
 from csle_rest_api.resources.emulations.routes import emulations_bp
 from csle_rest_api.resources.emulation_executions.routes import emulation_executions_bp
 from csle_rest_api.resources.simulations.routes import simulations_bp
@@ -64,7 +68,6 @@ from csle_rest_api.resources.config.routes import config_bp
 from csle_rest_api.resources.server_cluster.routes import server_cluster_bp
 from csle_rest_api.resources.version.routes import version_bp
 from csle_rest_api.resources.logs.routes import logs_bp
-from csle_rest_api.web_sockets.host_terminal.host_terminal import get_host_terminal_bp
 from csle_rest_api.web_sockets.container_terminal.container_terminal import get_container_terminal_bp
 import csle_rest_api.constants.constants as api_constants
 
@@ -114,6 +117,18 @@ def create_app(static_folder: str):
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.PGADMIN_RESOURCE}")
     app.register_blueprint(grafana_bp,
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.GRAFANA_RESOURCE}")
+    app.register_blueprint(cluster_status_bp,
+                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
+                                      f"{api_constants.MGMT_WEBAPP.CLUSTER_STATUS_RESOURCE}")
+    app.register_blueprint(nginx_bp,
+                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.NGINX_RESOURCE}")
+    app.register_blueprint(docker_bp,
+                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.DOCKER_RESOURCE}")
+    app.register_blueprint(flask_bp,
+                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.FLASK_RESOURCE}")
+    app.register_blueprint(postgresql_bp,
+                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
+                                      f"{api_constants.MGMT_WEBAPP.POSTGRESQL_RESOURCE}")
     app.register_blueprint(get_images_page_bp(static_folder=f"../../{static_folder}"),
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
                                       f"{api_constants.MGMT_WEBAPP.IMAGES_PAGE_RESOURCE}")
@@ -143,9 +158,6 @@ def create_app(static_folder: str):
     app.register_blueprint(get_user_admin_page_bp(static_folder=f"../../{static_folder}"),
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
                                       f"{api_constants.MGMT_WEBAPP.USER_ADMIN_PAGE_RESOURCE}")
-    app.register_blueprint(get_host_terminal_page_bp(static_folder=f"../../{static_folder}"),
-                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
-                                      f"{api_constants.MGMT_WEBAPP.HOST_TERMINAL_PAGE_RESOURCE}")
     app.register_blueprint(get_container_terminal_page_bp(static_folder=f"../../{static_folder}"),
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
                                       f"{api_constants.MGMT_WEBAPP.CONTAINER_TERMINAL_PAGE_RESOURCE}")
@@ -256,8 +268,6 @@ def create_app(static_folder: str):
     app.register_blueprint(logs_bp,
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
                                       f"{api_constants.MGMT_WEBAPP.LOGS_RESOURCE}")
-    web_sockets_host_terminal_bp = get_host_terminal_bp(app)
-    app.register_blueprint(web_sockets_host_terminal_bp)
     web_sockets_container_terminal_bp = get_container_terminal_bp(app)
     app.register_blueprint(web_sockets_container_terminal_bp)
 
@@ -267,10 +277,6 @@ def create_app(static_folder: str):
         :return: the root page of the management application
         """
         return app.send_static_file(api_constants.MGMT_WEBAPP.STATIC_RESOURCE_INDEX)
-
-    app.config[api_constants.MGMT_WEBAPP.HOST_TERMINAL_FD] = None
-    app.config[api_constants.MGMT_WEBAPP.HOST_TERMINAL_CMD] = [constants.COMMANDS.BASH]
-    app.config[api_constants.MGMT_WEBAPP.HOST_TERMINAL_CHILD_PID] = None
     socketio.init_app(app)
     return app
 
